nrb/graphs/nrb_histogram library

Classes

NrbHistogram
An interactive chart used to display the distribution of numerical data into bins. Visually similar to a bar chart, but bars are touching to represent continuous data. Tapping a bin displays a tooltip with its exact values.
NrbHistogramBin
Represents a single bin (range) in a histogram.