NrbHistogramBin class

Represents a single bin (range) in a histogram.

Constructors

NrbHistogramBin({required String label, required double frequency})
Constructor for the Histogram Bin.

Properties

frequency double
The frequency/count of items falling into this bin.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The label for this bin range (e.g., "0-10", "11-20").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited