NrbMultiBarChart class

A highly customizable, animated side-by-side (grouped) bar chart. Displays multiple series of data grouped together by category on the X-axis. Features smooth growth animations and interactive tooltips on tap.

Inheritance

Constructors

NrbMultiBarChart({Key? key, required List<NrbMultiBarSeries> series, required List<String> xAxisLabels, double width = double.infinity, double height = 250.0, Duration animationDuration = const Duration(milliseconds: 1000), Color gridColor = const Color(0xFFE0E0E0), Color textColor = const Color(0xFF757575)})
Constructor for the Multi-Bar Chart.
const

Properties

animationDuration → Duration
The duration of the vertical growth animation on load.
final
gridColor → Color
The color of the background horizontal grid lines.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The total height of the chart widget.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → List<NrbMultiBarSeries>
The list of data series to plot side-by-side.
final
textColor → Color
The color of the axis text.
final
width → double
The total width of the chart widget.
final
xAxisLabels → List<String>
The labels for the X-axis categories.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<NrbMultiBarChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited