NrbMultiBarSeries class

Represents a single data series in a multi-bar (grouped) chart.

Constructors

NrbMultiBarSeries({required List<double> data, required Color color, required String label})
Constructor for a multi-bar series.

Properties

color Color
The color of the bars for this series.
final
data List<double>
The list of numerical values for this series.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The label for this series (displayed in tooltips).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited