NrbPieChart class

A professional animated Pie Chart with interactive slice highlighting and optional labels.

Inheritance

Constructors

NrbPieChart({Key? key, required List<NrbPieSlice> slices, double size = 200.0, bool showLabels = true, PieLabelType labelType = PieLabelType.percentage, Color labelColor = Colors.white, Duration animationDuration = const Duration(milliseconds: 1000)})
Constructor for Pie Chart
const

Properties

animationDuration Duration
The duration of the expanding sweep animation on load.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor Color
The color of the text drawn on the slices.
final
labelType PieLabelType
What to display on the label if showLabels is true. Usually "percentage" or "label".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabels bool
Whether to show text labels directly on the slices.
final
size double
The diameter of the pie chart.
final
slices List<NrbPieSlice>
The list of data slices to plot.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NrbPieChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited