NrbPieSlice class
Represents a single slice in the pie chart.
Constructors
- NrbPieSlice({required double value, required Color color, required String label})
Properties
- color → Color
-
The color of this slice.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The label for this slice.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
The numerical value of this slice.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited