NrbScatterPlot class
An interactive chart that plots individual data points on an X/Y plane. Tapping a point displays a tooltip with its coordinates.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NrbScatterPlot
Constructors
-
NrbScatterPlot({Key? key, required List<
NrbScatterPoint> points, double width = double.infinity, double height = 250.0, Color pointColor = const Color(0xFF1E88E5), double pointRadius = 4.0, Color gridColor = const Color(0xFFE0E0E0), Color textColor = const Color(0xFF757575), Duration animationDuration = const Duration(milliseconds: 1000)}) -
Constructor for the Scatter Plot.
const
Properties
- animationDuration → Duration
-
The duration of the pop-in animation.
final
- gridColor → Color
-
The color of the background grid.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the entire chart widget.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- pointColor → Color
-
The color of the plotted dots.
final
- pointRadius → double
-
The radius of the plotted dots.
final
-
points
→ List<
NrbScatterPoint> -
The list of data points to plot.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color
-
The color of the axis text.
final
- width → double
-
The width of the entire chart widget.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NrbScatterPlot> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited