NrbScatterPoint class

Represents a single point (X, Y) on the scatter plot.

Constructors

NrbScatterPoint(double x, double y)
Constructor for the Scatter Point.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
The X-coordinate of the point.
final
y → double
The Y-coordinate of the point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited