textAlignment property
How the text should be aligned within the cell. Defaults to Alignment.center.
Implementation
final AlignmentGeometry textAlignment;
How the text should be aligned within the cell. Defaults to Alignment.center.
final AlignmentGeometry textAlignment;