NrbHeaderCell class

A modern header cell that supports HTML-like table spanning.

Inheritance

Constructors

NrbHeaderCell({Key? key, required String text, int colSpan = 1, int rowSpan = 1, Color backgroundColor = const Color(0xff04b935), Color foregroundColor = Colors.white, Color borderColor = Colors.white10, double textSize = 12, AlignmentGeometry textAlignment = Alignment.center, TextStyle? textStyle})
Creates an NrbHeaderCell with row and column spanning capabilities.
const

Properties

backgroundColor → Color
The background color of the header cell.
final
borderColor → Color
The border color of the header cell.
final
colSpan → int
How many columns this header should span horizontally. Defaults to 1.
final
foregroundColor → Color
The foreground color of the header text.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rowSpan → int
How many rows this header should span vertically. Defaults to 1.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The text displayed inside the header.
final
textAlignment → AlignmentGeometry
The alignment of the header text.
final
textSize → double
The fallback font size of the header text.
final
textStyle → TextStyle?
An optional custom TextStyle that overrides or merges with the default styling.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited