onDownloadCompleted property
Callback fired when the report is successfully downloaded and saved to bytes.
Implementation
final TableDownloadSuccessCallback? onDownloadCompleted;
Callback fired when the report is successfully downloaded and saved to bytes.
final TableDownloadSuccessCallback? onDownloadCompleted;