exportAlignment property
AlignmentGeometry?
get
exportAlignment
The alignment metadata used to format the cell during data export.
Implementation
AlignmentGeometry? get exportAlignment;
The alignment metadata used to format the cell during data export.
AlignmentGeometry? get exportAlignment;