exportIsBold property
bool
get
exportIsBold
A flag indicating if the text should be formatted as bold in exported documents.
Implementation
bool get exportIsBold;
A flag indicating if the text should be formatted as bold in exported documents.
bool get exportIsBold;