detach method

void detach()

Detaches the controller from the current reporting engine.

This should be called in the dispose method of your StatefulWidget to prevent memory leaks and clear callback references.

Implementation

void detach() {
  _getDataCallback = null;
  _downloadCallback = null;
}