getSubmitData method

List<List<String>> getSubmitData()

Extracts the current data of the report grid as a 2D List of Strings.

This is the primary way to retrieve data from an editable grid (e.g., pulling user input from TextFieldCells) for submission to an API or database.

Implementation

List<List<String>> getSubmitData() {
  if (_getDataCallback != null) {
    return _getDataCallback!();
  }
  return [];
}