getTextController method
Retrieves the registered text controller for a specific cell coordinate.
Implementation
TextEditingController? getTextController(int row, int col) {
return _textControllers["${row}_${col}"];
}
Retrieves the registered text controller for a specific cell coordinate.
TextEditingController? getTextController(int row, int col) {
return _textControllers["${row}_${col}"];
}