hasValidationErrors method
Checks if any cell in the grid currently contains a hard validation error.
Implementation
bool hasValidationErrors() {
return _cellStates.values.any((state) => state.errorText != null);
}
Checks if any cell in the grid currently contains a hard validation error.
bool hasValidationErrors() {
return _cellStates.values.any((state) => state.errorText != null);
}