overrideValue property

String? Function(String value, List<List<String>> gridData)? overrideValue
final

A callback that allows auto-correcting the user's input.

Return a new string to instantly override the field. If validate returns null, this triggers a Soft Correction (Yellow Border).

Implementation

final String? Function(String value, List<List<String>> gridData)? overrideValue;