showDownloadFloatingButton property
Determines whether to render the interactive Floating Action Button for exports.
Implementation
final bool showDownloadFloatingButton;
Determines whether to render the interactive Floating Action Button for exports.
final bool showDownloadFloatingButton;