primaryUiColor property
The background color for the main export Floating Action Button (FAB) and dialogs.
Implementation
final Color primaryUiColor;
The background color for the main export Floating Action Button (FAB) and dialogs.
final Color primaryUiColor;