primaryUiTextColor property
The foreground/text color for the main export Floating Action Button (FAB).
Implementation
final Color primaryUiTextColor;
The foreground/text color for the main export Floating Action Button (FAB).
final Color primaryUiTextColor;