TextFieldCell constructor
TextFieldCell({
- Key? key,
- TextEditingController? controller,
- String initialValue = '',
- ValueChanged<
String> ? onChanged, - double? cellWidth,
- double? cellHeight,
- double? textSize,
- AlignmentGeometry? textAlignment = Alignment.center,
- Color? backgroundColor = Colors.white,
- Color? textColor = Colors.black,
- Color? borderColor = Colors.black12,
- bool isBold = false,
- InputDecoration? decoration,
- TextInputType? keyboardType,
- List<
TextInputFormatter> ? inputFormatters,
Creates a TextFieldCell.
You can either provide a controller to manage state externally, or
provide an initialValue to let the cell manage its own controller.
Implementation
TextFieldCell({
super.key,
TextEditingController? controller,
String initialValue = '',
this.onChanged,
this.cellWidth,
this.cellHeight,
this.textSize,
this.textAlignment = Alignment.center,
this.backgroundColor = Colors.white,
this.textColor = Colors.black,
this.borderColor = Colors.black12,
this.isBold = false,
this.decoration,
this.keyboardType, // Included in constructor
this.inputFormatters, // Included in constructor
}) : controller = controller ?? TextEditingController(text: initialValue);