controller property
The controller that manages the text being edited.
If no controller is provided in the constructor, one is created automatically
using the initialValue.
Implementation
final TextEditingController controller;
The controller that manages the text being edited.
If no controller is provided in the constructor, one is created automatically
using the initialValue.
final TextEditingController controller;