The raw string representation of the cell's data.
This value is specifically used by the Excel Exporter to populate spreadsheet cells with the correct data.
@override String get exportValue => controller.text;