inputFormatters property
A list of formatters that restrict or format text as the user types.
Implementation
final List<TextInputFormatter>? inputFormatters;
A list of formatters that restrict or format text as the user types.
final List<TextInputFormatter>? inputFormatters;