onChanged property
A callback that is triggered whenever the text in the field changes.
Implementation
final ValueChanged<String>? onChanged;
A callback that is triggered whenever the text in the field changes.
final ValueChanged<String>? onChanged;