NrbNativeFileSaver class

Fallback file saver for unsupported Dart platforms.

Constructors

NrbNativeFileSaver()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

save(Uint8List bytes, String fileName) → Future<String>
Throws because the active platform has no NRB file-save implementation.