NrbEndpoints class abstract final

Shared production endpoints for NRB's existing export service.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

features → const String
Lists the export features enabled for a registered package.
processReport → const String
Processes the legacy report export payload.
processTable → const String
Processes the modern table export payload.