NrbNetworkClient class
A specialized network client for performing HTTP operations in a Web environment.
NrbNetworkClient utilizes the browser's web.XMLHttpRequest via package:web.
It provides high-performance asynchronous data fetching and is specifically
optimized for handling binary data transfers (ArrayBuffers) required for
report downloads.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
get(
String url, {Map< String, String> ? headers}) → Future<String> - Executes an HTTP GET request and returns the response body as a String.
-
postForBytes(
String url, String body, {Map< String, String> ? headers}) → Future<Uint8List> - Executes an HTTP POST request and returns the response body as Uint8List bytes.