NrbTableExporter class

New Engine exporter

Constructors

NrbTableExporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateReportJson({required int featureId, required List<List<NrbHeaderCell>> headers, required List<List<ReportCell>> tableData, required String packageName, required String reportName}) String
Generates a JSON string representing the entire report structure and data.