NrbToast class

A simple utility class for displaying lightweight, floating notifications.

NrbToast leverages the Flutter ScaffoldMessenger and SnackBar with a floating behavior to mimic a native mobile toast notification.

Constructors

NrbToast()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showToast(BuildContext context, String message, {String? title}) → void
Displays a floating toast notification on the screen.