nrb/utils/report_downloader_io library

Classes

ReportDownloader
A specialized utility for handling report downloads in a Native (IO) environment.

Typedefs

DownloadSuccessCallback = void Function(Uint8List bytes, String fileName)
A callback function triggered after a report has been successfully retrieved from the server.