nrb/utils/report_downloader_web library

Classes

ReportDownloader
A specialized utility for handling report downloads in a Web environment.

Typedefs

DownloadSuccessCallback = void Function(Uint8List bytes, String fileName)
A callback function triggered after a report has been successfully downloaded from the server.