onDownloadCompleted property
Callback fired when the report is successfully downloaded and saved to bytes.
Implementation
final DownloadSuccessCallback? onDownloadCompleted;
Callback fired when the report is successfully downloaded and saved to bytes.
final DownloadSuccessCallback? onDownloadCompleted;