tableData property
The 2D matrix of report data cells representing the main body grid.
Implementation
final List<List<ReportCell>> tableData;
The 2D matrix of report data cells representing the main body grid.
final List<List<ReportCell>> tableData;