CellNumberFormat enum
Defines the number formatting styles available for a cell.
Values
- none → const CellNumberFormat
-
No formatting applied.
- international → const CellNumberFormat
-
Formats numbers using the international system (e.g., 1,234,567).
- indian → const CellNumberFormat
-
Formats numbers using the Indian numbering system (e.g., 12,34,567).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CellNumberFormat> - A constant List of the values in this enum, in order of their declaration.