NrbLineChart class
A professional line chart with area gradient fill, drawing animation, optional axes, and interactive tooltips.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NrbLineChart
Constructors
-
NrbLineChart({Key? key, required List<
double> data, List<String> ? xAxisLabels, double width = double.infinity, double height = 200.0, Color lineColor = const Color(0xFF0B7A3E), double lineWidth = 2.5, Duration animationDuration = const Duration(milliseconds: 1500), bool showGrid = false, Color gridColor = const Color(0xFFE0E0E0), Color textColor = const Color(0xFF757575)}) -
Constructor for the Line Chart.
const
Properties
- animationDuration → Duration
-
The duration of the line drawing animation.
final
-
data
→ List<
double> -
The list of data points to plot.
final
- gridColor → Color
-
The color of the background grid lines (if shown).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the entire chart widget.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineColor → Color
-
The color of the main line.
final
- lineWidth → double
-
The thickness of the main line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGrid → bool
-
Whether to show the background grid, Y-axis labels, and enable tooltips.
final
- textColor → Color
-
The color of the axis text (if shown).
final
- width → double
-
The width of the entire chart widget.
final
-
xAxisLabels
→ List<
String> ? -
The list of labels for the X-axis (optional).
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NrbLineChart> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited