NrbMultiDonutChart class
A professional, animated multi-segment donut chart. Supports smooth initial drawing animations, interactive tap events, internal labels, and automatically generated side/bottom legends.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- NrbMultiDonutChart
Constructors
-
NrbMultiDonutChart({Key? key, required List<
NrbPieSlice> slices, double size = 200.0, double strokeWidth = 35.0, Widget? centerContent, bool showLabels = false, Color labelColor = Colors.white, bool showSideLegend = false, bool showBottomLegend = false, Duration animationDuration = const Duration(milliseconds: 1000)}) -
Constructor for the Multi-Donut Chart.
const
Properties
- animationDuration → Duration
-
The duration of the initial expanding sweep animation.
final
- centerContent → Widget?
-
An optional widget to display in the hollow center of the donut.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelColor → Color
-
The color of the text labels inside the segments.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBottomLegend → bool
-
Whether to automatically generate and display a dot legend below the chart.
final
- showLabels → bool
-
Whether to display the percentage value inside the donut segments.
final
- showSideLegend → bool
-
Whether to automatically generate and display a legend to the right of the chart.
final
- size → double
-
The total width and height of the circular chart itself.
final
-
slices
→ List<
NrbPieSlice> -
The list of data slices to plot on the donut.
final
- strokeWidth → double
-
The thickness of the donut ring.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< NrbMultiDonutChart> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited