NrbLineSeries class
Represents a single line of data in the multi-line chart.
Constructors
-
NrbLineSeries({required List<
double> data, required Color color, required String label}) - Constructor for the line series.
Properties
- color → Color
-
The color of the line.
final
-
data
→ List<
double> -
The data points for this series.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The label for this series.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited