nrb/graphs/nrb_scatter_plot library
Classes
- NrbScatterPlot
- An interactive chart that plots individual data points on an X/Y plane. Tapping a point displays a tooltip with its coordinates.
- NrbScatterPoint
- Represents a single point (X, Y) on the scatter plot.