nrb/report_controller library
Classes
- CellFormState
- Tracks the internal validation and override state of an interactive cell.
- ReportController
- A controller used to programmatically interact with a ReportMaker grid.
- ReportFormRule
- Represents a dynamic form validation and auto-correction rule applied to a specific cell.
Typedefs
-
DownloadReportCallback
= Future<
void> Function() - A function signature for triggering a report download or export.
-
GetReportDataCallback
= List<
List< Function()String> > - A function signature for retrieving the current state of the entire report data.
-
GetTableDataOnlyCallback
= List<
List< Function()String> > - A function signature for retrieving only the main body grid data (excluding left column).