nrb/report_controller library

Classes

ReportController
A controller used to programmatically interact with a ReportMaker or ReportDesignBuilder widget.

Typedefs

DownloadReportCallback = Future<void> Function()
A function signature for triggering a report download or export.
GetReportDataCallback = List<List<String>> Function()
A function signature for retrieving the current state of the report data.