CellFormState class
Tracks the internal validation and override state of an interactive cell.
Constructors
- CellFormState({String? errorText, bool isOverridden = false, String? overrideMessage})
Properties
- errorText ↔ String?
-
The active error message, causing a Red UI state.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverridden ↔ bool
-
Indicates if the engine automatically altered the user's input.
getter/setter pair
- overrideMessage ↔ String?
-
The active correction message, causing a Yellow UI state (if errorText is null).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited