ReportController class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
{GetReportDataCallback? dataCallback, DownloadReportCallback? downloadCallback}) → void - Internal method used by ReportDesignBuilder to attach logic.
-
detach(
) → void - Internal method to detach the controller and prevent memory leaks.
-
downloadReport(
) → Future< void> - Trigger the internal download/export logic from an external button.
-
getSubmitData(
) → List< List< String> > - Extract the current data of the report grid as a 2D List of Strings.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited