ReportController class
A controller used to programmatically interact with a ReportMaker or ReportDesignBuilder widget.
By passing an instance of ReportController to your report widget, you can extract data (including values from TextFieldCell) and trigger downloads from external UI elements like custom AppBars.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
{GetReportDataCallback? dataCallback, DownloadReportCallback? downloadCallback}) → void - Internal method used by the reporting engine to attach logic to this controller.
-
detach(
) → void - Detaches the controller from the current reporting engine.
-
downloadReport(
) → Future< void> - Programmatically triggers the internal download/export logic.
-
getSubmitData(
) → List< List< String> > - Extracts the current data of the report grid as a 2D List of Strings.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited