ReportController class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(GetReportDataCallback callback)
→ void
-
Internal method used by ReportDesignBuilder to attach the data extraction logic.
-
detach()
→ void
-
Internal method to detach the controller and prevent memory leaks.
-
getSubmitData()
→ List<List<String>>
-
Call this method from anywhere in your app to extract the current data
of the report grid as a 2D List of Strings.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited