detach method
void
detach()
Internal method to detach the controller and prevent memory leaks.
Implementation
void detach() {
_getDataCallback = null;
_downloadCallback = null;
}
Internal method to detach the controller and prevent memory leaks.
void detach() {
_getDataCallback = null;
_downloadCallback = null;
}