getSubmitData method

List<List<String>> getSubmitData()

Call this method from anywhere in your app to extract the current data of the report grid as a 2D List of Strings.

Implementation

List<List<String>> getSubmitData() {
  if (_getDataCallback != null) {
    return _getDataCallback!();
  }
  // If called before the widget is built or if detached
  return [];
}