ReportFormRule class
Represents a dynamic form validation and auto-correction rule applied to a specific cell.
This rule engine supports both Soft Corrections (Yellow UI) and Hard Errors (Red UI).
Constructors
-
ReportFormRule({required int rowIndex, required int colIndex, required String? validate(String value, List<
List< gridData), String? overrideValue(String value, List<String> >List< gridData)?, String? overrideMessage(String value, List<String> >List< gridData)?})String> > - Creates a ReportFormRule for dynamic grid validation.
Properties
- colIndex → int
-
The column index in the
tableDatagrid where this rule applies.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
overrideMessage
→ String? Function(String value, List<
List< gridData)?String> > -
A custom message to display in the UI tooltip when overrideValue successfully changes the input.
final
-
overrideValue
→ String? Function(String value, List<
List< gridData)?String> > -
A callback that allows auto-correcting the user's input.
final
- rowIndex → int
-
The row index in the
tableDatagrid where this rule applies.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validate
→ String? Function(String value, List<
List< gridData)String> > -
A callback that evaluates the raw user input against the current grid state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited