validate property

String? Function(String value, List<List<String>> gridData) validate
final

A callback that evaluates the raw user input against the current grid state.

Return an error string to trigger a Hard Error (Red Border). Return null if the input is valid or if you only want a Soft Correction (Yellow Border).

Implementation

final String? Function(String value, List<List<String>> gridData) validate;