NrbNetworkClient class
A low-level network client for performing HTTP operations on Native platforms.
NrbNetworkClient uses the standard HttpClient from dart:io to execute
GET and POST requests. It is designed to handle common reporting tasks,
such as fetching configuration JSON or downloading file bytes.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
get(
String url, {Map< String, String> ? headers}) → Future<String> - Executes an HTTP GET request and returns the response body as a String.
-
postForBytes(
String url, String body, {Map< String, String> ? headers}) → Future<Uint8List> - Executes an HTTP POST request and returns the response body as Uint8List bytes.