NrbExporter class
A utility class responsible for converting report data into a JSON payload.
NrbExporter takes the high-level widget data (headers, sub-headers, and cells) and transforms them into a structured JSON format suitable for export services (e.g., generating Excel or PDF files on the server).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateReportJson(
{required int featureId, required List< HeaderCell> headers, required List<SubHeaderCell> subHeaders, required List<ReportCell> leftColumn, required List<List< tableData, required String packageName, required String stickyHeaderLabel, required Color stickyHeaderBackgroundColor, Color stickyHeaderTextColor = Colors.white, required String reportName}) → StringReportCell> > - Generates a JSON string representing the entire report structure and data.