NrbNativePdfGenerator class
A pure Dart PDF generator that creates a PDF document from table data without using any third-party packages.
Follows the PDF 1.7 specification with responsive layout features matching the server-side ReportLab engine.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generate(
{required String? companyName, required String? companyAddress, required Uint8List? companyLogoBytes, int? logoWidth, int? logoHeight, required String reportName, required List< List< headers, required List<NrbHeaderCell> >List< tableData, required List<ReportCell> >double> columnWidths}) → Future<Uint8List>