DownloadSuccessCallback typedef
A callback function triggered after a report has been successfully processed and downloaded.
Provides the raw bytes of the file and the resulting fileName.
Implementation
typedef DownloadSuccessCallback = void Function(
Uint8List bytes, String fileName);