ReportDownloader class
A stub implementation of the ReportDownloader.
This class defines the interface for downloading reports. Platform-specific implementations (Web and IO) will override this behavior at runtime via conditional imports.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
downloadReport(
BuildContext context, {required int featureId, required String fileExtension, required String? reportName, required List< HeaderCell> headers, required List<SubHeaderCell> subHeaders, required List<ReportCell> leftColumn, required List<List< tableData, required String serverUrl, required String packageName, required String apiKey, required String stickyHeaderLabel, required Color stickyHeaderBackgroundColor, required Color stickyHeaderTextColor, DownloadSuccessCallback? onSuccess}) → Future<ReportCell> >void> - Defines the signature for the platform-specific download method.