ReportDownloader class
A specialized utility for handling report downloads in a Web environment.
ReportDownloader orchestrates the flow of exporting grid data to JSON,
communicating with the NRB backend, and triggering the native browser
download dialog using modern package:web APIs.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
downloadReport(
BuildContext context, {required int featureId, required String fileExtension, String? reportName, required List< HeaderCell> headers, required List<SubHeaderCell> subHeaders, required List<ReportCell> leftColumn, required List<List< tableData, required String serverUrl, required String packageName, required String apiKey, required String stickyHeaderLabel, required Color stickyHeaderBackgroundColor, required Color stickyHeaderTextColor, DownloadSuccessCallback? onSuccess}) → Future<ReportCell> >void> - Sends report data to the server and triggers a browser file download.