ReportMaker class

Inheritance

Constructors

ReportMaker({Key? key, double cellWidth = 100, double bodyCellHeight = 35, double headerHeight = 30, double textSize = 12, double headerTextSize = 13, required List<HeaderCell> headers, required List<SubHeaderCell> subHeaders, required List<ReportCell> leftColumn, required List<List<ReportCell>> tableData, String stickyHeaderLabel = "Header", Color stickyHeaderBackgroundColor = Colors.blue, Color stickyHeaderForegroundColor = Colors.white, bool enableDownload = true, DownloadSuccessCallback? onDownloadCompleted, ReportController? controller})
const

Properties

bodyCellHeight double
final
cellWidth double
final
controller ReportController?
final
enableDownload bool
final
hashCode int
The hash code for this object.
no setterinherited
headerHeight double
final
headers List<HeaderCell>
final
headerTextSize double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftColumn List<ReportCell>
final
onDownloadCompleted DownloadSuccessCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickyHeaderBackgroundColor Color
final
stickyHeaderForegroundColor Color
final
stickyHeaderLabel String
final
subHeaders List<SubHeaderCell>
final
tableData List<List<ReportCell>>
final
textSize double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited